#
# spec file for package libevtx
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libevtx
%define lname	libevtx1
%define timestamp	20160107
Version:        0~%timestamp
Release:        bp153.1.15
Summary:        Library and tools to access the Windows XML Event Log (EVTX) format
License:        LGPL-3.0+ and GFDL-1.3
Group:          Productivity/File utilities
Url:            https://github.com/libyal/libevtx/wiki
Source:         https://github.com/libyal/libevtx/releases/download/%timestamp/%name-alpha-%timestamp.tar.gz
Source2:        Windows_XML_Event_Log_(EVTX).pdf
BuildRequires:  pkg-config
BuildRequires:  python-devel
#latest version of these in OBS as of Jan 28, 2016
BuildRequires:  pkgconfig(libbfio) >= 20160108
BuildRequires:  pkgconfig(libcdata) >= 20130407
BuildRequires:  pkgconfig(libcdirectory) >= 20120425
BuildRequires:  pkgconfig(libcfile) >= 20130609
BuildRequires:  pkgconfig(libclocale) >= 20150101
BuildRequires:  pkgconfig(libcnotify) >= 20150101
BuildRequires:  pkgconfig(libcpath) >= 20130609
BuildRequires:  pkgconfig(libcsplit) >= 20130609
BuildRequires:  pkgconfig(libcsystem) >= 20150629
BuildRequires:  pkgconfig(libexe) >= 20120405
BuildRequires:  pkgconfig(libfcache) >= 20120405
BuildRequires:  pkgconfig(libfdata) >= 20120405
BuildRequires:  pkgconfig(libregf) >= 20140803
BuildRequires:  pkgconfig(libuna) >= 20130609
BuildRequires:  pkgconfig(libwrc) >= 20140803

#testing fails if the factory package is used, use the internal version
#verified 2/2/2016
#BuildRequires:  pkgconfig(libfvalue) > 20151226
#BuildRequires:  pkgconfig(libfguid) >= 20150104
#BuildRequires:  pkgconfig(libfdatetime) >= 20150507
#BuildRequires:  pkgconfig(libfwnt) >= 20151206
#BuildRequires:  pkgconfig(libfwevt) >= 20160103
#build fails if the factory package is used, use the internal version
#verified 1/28/2016
#BuildRequires:  pkgconfig(libcstring) > 20150101
#BuildRequires:  pkgconfig(libcerror) > 20150407
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Library and tools to access the Windows XML Event Log (EVTX) format.
For the Windows pre-XML Event Log (EVT) format, see libevt.

%package -n %lname
Summary:        Library to access the Windows XML Event Log (EVTX) format
License:        LGPL-3.0+
Group:          System/Libraries

%description -n %lname
Library to access the Windows Event Log (EVT) format.
For the Windows pre-XML Event Log (EVT) format, see libevt.

%package tools
Summary:        Utilities to export events from Windows XML event files (EVTX)
License:        LGPL-3.0+
Group:          Productivity/File utilities

%description tools
Tools for parsing EVTX files. These include evtxinfo and evtxexport.

%package devel
Summary:        Development files for libevtx, a Windows XML Event file parser
License:        LGPL-3.0+ and GFDL-1.3
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libevtx is a library to access the Windows XML Event log format.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%package -n python-%name
Summary:        Python bindings for libevtx
License:        LGPL-3.0+
Group:          Development/Libraries/Python
Requires:       %lname = %version
Requires:       python
Provides:       pyevtx = %version

%description -n python-%name
Python bindings for libevtx, which can read Windows XML Event files.

%prep
%setup -qn libevtx-%timestamp
cp "%SOURCE2" .

%build
%configure --disable-static --enable-wide-character-type --enable-python
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
find %buildroot -name '*.la' -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%_libdir/libevtx.so.*

%files tools
%defattr(-,root,root)
%_bindir/evtx*
%_mandir/man1/evt*.1*

%files devel
%defattr(-,root,root)
%doc Windows_XML_Event_Log*.pdf
%_includedir/libevtx.h
%_includedir/libevtx/
%_libdir/libevtx.so
%_libdir/pkgconfig/libevtx.pc
%_mandir/man3/libevtx.3*

%files -n python-%name
%defattr(-,root,root)
%doc AUTHORS COPYING README
%python_sitearch/pyevtx.so

%changelog
* Tue Jan 26 2016 Greg.Freemyer@gmail.com
- update to v0~20160107
  * 2016 update
  * worked on Python 3 support
  * Worked on format support
  * applied updates
  * worked on Python bindings
  * updated m4 scripts
  * changed version for pypi repacking
  * worked on setup.py
- use internal libfwevt.  fixes failures found in integration testing with plaso
* Mon Jan 12 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
- Use libyal packages from OBS where appropriate
  * test the builds by running "run_tests.py" from the plaso tarball
  * don't use OBS packages thst introduce test failures.
* Mon Dec 22 2014 Greg.Freemyer@gmail.com
- update to 0~20141112
  * changes to expose the event identifier qualifiers in the python bindings
  * updated dependencies and corresponding changes
  * update Python-bindings tests
- update URL and Source fields to use the new github site
* Fri Sep 19 2014 Greg.Freemyer@gmail.com
- update to 0~20140901
  * bug fix in Python-bindings
- update Source: field to have fullpath, delete DL_URL
* Thu Aug 28 2014 Greg.Freemyer@gmail.com
- testing failed, passes if these 2 internal packages are used
  * libfguid
  * libfdatetime
* Tue Aug 26 2014 Greg.Freemyer@gmail.com
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Requires:     %%lname = %%version
  * Provides:	pyevtx = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to 0~20140731
  * bug fix in Python-bindings
  * worked on dpkg debug packages support
  * updated dependencies
  * worked on Python-bindings
  * replaced PackageMaker for pkgbuild
  * code clean up
  * worked on setup.py
  * added evtxexport man page
  * removed examples
  * 2014 update
  * small fix in evtxexport -h output
- use libregf from external package
* Tue Nov 26 2013 Greg.Freemyer@gmail.com
- using internal libregf, latest factory update broke libevtx
* Mon Nov  4 2013 Greg.Freemyer@gmail.com
- update to 0~20131013
  * updated dependencies
- using internal libwrc, latest factory update broke libevtx
- removed 0~ from buildrequires dependencies
* Wed Oct  2 2013 Greg.Freemyer@gmail.com
-  update to 0~20130923
  * updated dependencies
  * worked on libcthreads build support
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- update to 0~20130727
  * updated dependencies
  * pyevtx
  - changed event identifier to an unsigned long
  - fixes for >2G file objects in BFIO glue code
  - other updates and bug fixes
  * removed unnecessary restriction in library include headers
  * worked on tests
  * improved reading from dirty files with an incorrect number of chunks
  * fix for encoding special characters in XML output
  * added support for parsing ProcessingErrorData
  * worked on improving corruption detection for recovered records
  * textual changes
  * fixed codepage 1255 restriction
  * improvements to message string support
- changed to gz compression to simplyfy donwload/convert
- used factory version of libyal libraries if possible
* Mon Apr  8 2013 Greg.Freemyer@gmail.com
- update to 0~20130329
  * bug fix for recent libfdata changes
* Thu Apr  4 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; remove unused %%py_requires; do not bloat shlib package
  with documentation
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130319) for build.opensuse.org
